Interface AudienceProvider<C>
- Type Parameters:
C- Command sender type
- All Superinterfaces:
Function<@NonNull C,@NonNull net.kyori.adventure.audience.Audience>
- Functional Interface:
- This is a functional interface and can therefore be used as the assignment target for a lambda expression or method reference.
@FunctionalInterface
public interface AudienceProvider<C>
extends Function<@NonNull C,@NonNull net.kyori.adventure.audience.Audience>
Function that maps the command sender type to an adventure
Audience-
Method Summary
Modifier and TypeMethodDescription@NonNull net.kyori.adventure.audience.AudienceConvert a command sender to anAudiencestatic <C extends net.kyori.adventure.audience.Audience>
AudienceProvider<C>Get an audience provider for sender types which are already anAudience.
-
Method Details
-
apply
Convert a command sender to anAudience -
nativeAudience
Get an audience provider for sender types which are already anAudience.- Type Parameters:
C- sender type- Returns:
- native audience provider
- Since:
- 1.5.0
-